timesignaturetools.get_nonbinary_factor_from_time_signature_denominator
=======================================================================

.. autofunction:: abjad.tools.timesignaturetools.get_nonbinary_factor_from_time_signature_denominator.get_nonbinary_factor_from_time_signature_denominator
